Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/matomo-org/matomo.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authormatt <matt@59fd770c-687e-43c8-a1e3-f5a4ff64c105>2008-10-28 14:42:44 +0300
committermatt <matt@59fd770c-687e-43c8-a1e3-f5a4ff64c105>2008-10-28 14:42:44 +0300
commit255b887a67c9eb6eaac2ff243b3879756d6cb802 (patch)
tree40acb631d96976a11160e9f4317cbb47a023c725 /core/ViewDataTable.php
parentc1027ca9be90fd572bf6aafc690b7d93e6c75e40 (diff)
- renaming all instances of LogStats to Tracker for clarity
- improving error message to be prettier - adding footer in all admin pages for consistency
Diffstat (limited to 'core/ViewDataTable.php')
-rw-r--r--core/ViewDataTable.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/core/ViewDataTable.php b/core/ViewDataTable.php
index 2503d23eb5..d367097278 100644
--- a/core/ViewDataTable.php
+++ b/core/ViewDataTable.php
@@ -455,7 +455,7 @@ abstract class Piwik_ViewDataTable
* - etc.
*
* The values are loaded:
* - from the generic filters that are applied by default @see Piwik_API_Request::getGenericFiltersInformation()
* - from the values already available in the GET array
* - from the values set using methods from this class (eg. setSearchPattern(), setLimit(), etc.)
*
@@ -466,7 +466,7 @@ abstract class Piwik_ViewDataTable
// build javascript variables to set
$javascriptVariablesToSet = array();
- $genericFilters = Piwik_API_Request::getGenericFiltersInformation();
+ $genericFilters = Piwik_API_ResponseBuilder::getGenericFiltersInformation();
foreach($genericFilters as $filter)
{
foreach($filter as $filterVariableName => $filterInfo)
@@ -455,7 +455,7 @@ abstract class Piwik_ViewDataTable
*
* The values are loaded:
- * - from the generic filters that are applied by default @see Piwik_API_Request::getGenericFiltersInformation()
+ * - from the generic filters that are applied by default @see Piwik_API_ResponseBuilder::getGenericFiltersInformation()
* - from the values already available in the GET array
* - from the values set using methods from this class (eg. setSearchPattern(), setLimit(), etc.)